@@ -3,7 +3,7 @@ BEGIN {
   $Dist::Zilla::PluginBundle::SCHWIGON::AUTHORITY = 'cpan:SCHWIGON';
 }
 # ABSTRACT: Build your distributions like SCHWIGON does
-$Dist::Zilla::PluginBundle::SCHWIGON::VERSION = '0.015';
+$Dist::Zilla::PluginBundle::SCHWIGON::VERSION = '0.016';
 # (well actually like FLORA - as it is shamelessly stolen)
 
 use Moose 1.00;
@@ -140,6 +140,12 @@ has skip_pod_modules => (
     },
 );
 
+has test_compile_skip => (
+    is        => 'ro',
+    isa       => Str,
+    predicate => 'has_test_compile_skip',
+);
+
 method _build_homepage_url {
     return sprintf $self->_cpansearch_pattern, $self->dist;
 }
@@ -319,9 +325,14 @@ method configure {
         MetaJSON
         PkgVersion
         PodSyntaxTests
-        Test::Compile
     ));
 
+    $self->add_plugins(['Test::Compile' => {
+                                            $self->has_test_compile_skip
+                                            ? (skip => $self->test_compile_skip)
+                                            : (),
+                                           }]);
+
     $self->add_plugins('Test::NoTabs')
         unless $self->disable_tab_tests;
 
